@@ -4,7 +4,8 @@ from django.contrib import admin
 from .models import SiteConfigModel
 
 class SiteConfigModelAdmin(admin.ModelAdmin):
-    pass
+    list_display = ["key", "site"]
+    search_fields = ["key", "site__name"]
 
 
 admin.site.register(SiteConfigModel, SiteConfigModelAdmin)
